#
# This file is part of Efforia project.
#
# Copyright (C) 2011-2013 William Oliveira de Lagos <william@efforia.com.br>
#
# Efforia is free software: you can redistribute it and/or modify
# it under the terms of the Lesser GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Efforia is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with Efforia. If not, see <http://www.gnu.org/licenses/>.
#
#!/usr/bin/python
# -*- coding: utf-8 -*-
from social import Search,Follows,ID,Deletes,Authentication,Twitter,Facebook,Tutorial,Coins

def discharge(request):
    c = Coins()
    if request.method == 'GET':
        c.discharge(request)

def recharge(request):
    c = Coins()
    if request.method == 'GET':
        c.recharge(request)

def balance(request):
    c = Coins()
    if request.method == 'GET':
        c.balance(request)

def payment(request):
    pay = Coins()
    if request.method == 'GET':
        return pay.view_recharge(request)
    elif request.method == 'POST':
        return pay.update_credit(request)

def search(request):
    s = Search()
    if request.method == 'GET':
        return s.explore(request)

def explore(request):
    p = Profiles()
    if request.method == 'GET':
        return p.view_userinfo(request)

def activity(request):
    p = Profiles()
    if request.method == 'GET':
        return p.view_activity(request)

def following(request):
    fav = Follows()
    if request.method == 'GET':
        return fav.view_following(request)

def follow(request):
    f = Follows()
    if request.method == 'GET':
        return f.become_follower(request)

def unfollow(request):
    f = Follows()
    if request.method == 'GET':
        return f.leave_follower(request)

def ids(request):
    i = ID()
    if request.method == 'GET':
        return i.view_id(request)
    elif request.method == 'POST':
        return i.finish_tutorial(request)

def delete(request):
    d = Deletes()
    if request.method == 'GET':
        return d.delete_element(request)

def profile(request):
    prof = Profiles()
    if request.method == 'GET':
        return prof.view_profile(request)
    elif request.method == 'POST':
        return prof.update_profile(request)

def authenticate(request):
    a = Authentication()
    if request.method == 'GET':
        return a.authenticate(request)

def leave(request):
    a = Authentication()
    if request.method == 'GET':
        return a.leave(request)

def twitter_post(request):
    t = Twitter()
    if request.method == 'GET':
        return t.update_status(request)

def facebook_post(request):
    f = Facebook()
    if request.method == 'GET':
        return f.update_status(request)

def facebook_event(request):
    f = Facebook()
    if request.method == 'GET':
        return f.send_event(request)
    
def facebook_eventcover(request):
    f = Facebook()
    if request.method == 'GET':
        return f.send_event_cover(request)
    
def participate(request):
    a = Authentication()
    if request.method == 'GET':
        return a.view_register(request)
    elif request.method == 'POST':
        return a.participate(request)

def tutorial(request):
    t = Tutorial()
    if request.method == 'GET':
        return t.view_tutorial(request)
    elif request.method == 'POST':
        return t.finish_tutorial(request)


from django.contrib.auth.models import User
from django.conf import settings
from django.shortcuts import render

def user(name): return User.objects.filter(username=name)[0]
def superuser(): return User.objects.filter(is_superuser=True)[0]

class Socialize():
    def __init__(self): pass
    def verify_permissions(self,request):
        perm = 'super'
        if 'permissions' in request.COOKIES:
            perm = request.COOKIES['permissions']
        permissions = True if 'super' in perm else False
        return permissions
    def start(self,request):
        # Painel do usuario
        # u = user('efforia'); 
        # permissions = self.verify_permissions(request)
        # actions = settings.EFFORIA_ACTIONS; apps = []
        # for a in settings.EFFORIA_APPS: apps.append(actions[a])
        # return render(request,'interface.html',{'static_url':settings.STATIC_URL,
        #                                     'user':user('efforia'),'perm':permissions,
        #                                     'name':'%s %s' % (u.first_name,u.last_name),'apps':apps
        #                                     },content_type='text/html')
        # Pagina inicial
        return render(request,'index.html',{'static_url':settings.STATIC_URL},content_type='text/html')
    def external(self,request):
        u = self.current_user(request)
        sellables = Sellable.objects.filter(user=u)
        for s in sellables: s.paid = True
        return self.redirect('/')
    def profile_view(self,request,name):
        if len(list(User.objects.filter(username=name))) > 0: request.session['user'] = name
        r = redirect('/')
        r.set_cookie('permissions','view_only')
        return r
    def json_decode(self,string):
        j = json.loads(string,'utf-8')
        return ast.literal_eval(j)
    def url_request(self,url,data=None,headers={}):
        request = urllib2.Request(url=url,data=data,headers=headers)
        request_open = urllib2.urlopen(request)
        return request_open.geturl()
    def do_request(self,url,data=None,headers={}):
        response = ''
        request = urllib2.Request(url=url,data=data,headers=headers)
        try:
            request_open = urllib2.urlopen(request)
            response = request_open.read()
            request_open.close()
        except urllib2.HTTPError,e:
            print url
            print data
            print headers
            print e.code
            print e.msg
            print e.hdrs
            print e.fp
        return response
    def object_token(self,token):
        relations = settings.EFFORIA_TOKENS
        typobject = relations[token]
        return typobject
    def object_byid(self,token,ident):
        obj = self.object_token(token)
        return globals()[obj].objects.filter(id=ident)[0]
    def convert_datetime(self,date_value):
        d = time.strptime(date_value,'%d/%m/%Y')
        return datetime.fromtimestamp(time.mktime(d))
    def authenticate(self,username,password):
        exists = User.objects.filter(username=username)
        if exists:
            if exists[0].check_password(password): 
                return exists
        else: return None
    def authenticated(self):
        name = self.get_current_user()
        if not name: 
            #self.redirect('login')
            self.render('templates/enter.html',STATIC_URL=settings.STATIC_URL)
            return False
        else:
            return True
    def accumulate_points(self,points,request=None):
        if request is None: u = self.current_user()
        else: u = self.current_user(request)
        current_profile = Profile.objects.all().filter(user=u)[0]
        current_profile.points += points
        current_profile.save()



#
# This file is part of Efforia Open Source Initiative.
#
# Copyright (C) 2011-2013 William Oliveira de Lagos <william@Socialize.com.br>
#
# Socialize is free software: you can redistribute it and/or modify
# it under the terms of the Lesser GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Socialize is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with Socialize. If not, see <http://www.gnu.org/licenses/>.
#
#!/usr/bin/python
# -*- coding: utf-8 -*-

import json,urllib,urllib2,re,logging,oauth2 as oauth
from datetime import datetime
from time import mktime,strptime

from django.http import HttpResponse as response
from django.http import HttpResponseRedirect as redirect
from django.shortcuts import render
from django.db import IntegrityError
from django.contrib.auth.models import AnonymousUser, User
#from tastypie.authentication import Authentication
#from provider.oauth2.models import AccessToken

from models import *
from forms import TutorialForm
from core import Socialize

class Search(Socialize):
    def __init__(self): pass
    def explore(self,request):
        try: query = request.GET['explore']
        except KeyError,e: query = ''
        u = self.current_user(request)
        others = [x['id'] for x in Profile.objects.values('id')]
        objects = self.feed(u,others)
        filter(lambda obj: query.lower() in obj.name.lower(),objects)  
        return self.view_mosaic(request,objects) 

class Follows(Socialize):
    def __init__(self): pass
    def view_following(self,request):
        u = self.current_user(request); rels = []
        for f in Followed.objects.filter(follower=u.id):
            rels.append(Profile.objects.filter(user_id=f.followed)[0])
        request.COOKIES['permissions'] = 'view_only'
        return self.view_mosaic(request,rels)
    def become_follower(self,request):
        u = self.current_user(request).id
        followed = Profile.objects.filter(id=request.GET['profile_id'])[0].user_id
        follow = Followed(followed=followed,follower=u)
        follow.save()
        return response('Profile followed successfully')
    def leave_follower(self,request):
        u = self.current_user(request).id
        followed = request.GET['profile_id']
        query = Followed.objects.filter(followed=followed,follower=u)
        if len(query): query[0].delete()
        return response('Profile unfollowed successfully')


class ID(Socialize):
    def __init__(self): pass
    def view_id(self,request):
        u = self.current_user(request)
        if 'first_turn' in request.GET:
            if u.profile.first_turn: return response('yes')
            else: return response('no')
        elif 'object' in request.GET:
            o,t = request.GET['object'][0].split(';')
            now,objs,rels = self.get_object_bydate(o,t)
            obj = globals()[objs].objects.all().filter(date=now)[0]
            if hasattr(obj,'user'): return response(str(obj.user.id))
            else: return response(str(self.current_user().id))
        else: return response(str(self.current_user().id))
    def finish_tutorial(self,request):
        u = self.current_user(request)
        p = Profile.objects.all().filter(user=u)[0]
        p.first_time = False
        p.save()
        return response('Tutorial finalizado.')        

class Deletes(Socialize):
    def delete_element(self,request):
        oid = request.GET['id']
        modobj = settings.Socialize_TOKENS[request.GET['token']]
        module,obj = modobj.split('.')
        o = self.class_module('%s.models'%module,obj)
        query = o.objects.filter(id=oid)
        if len(query): query[0].delete()
        return response('Object deleted successfully')
    
class Tutorial(Socialize):
    def view_tutorial(self,request):
        social = False if 'social' not in request.GET else True
        form = TutorialForm()
        return render(request,'tutorial.html',{'form':form,'static_url':settings.STATIC_URL,'social':social})
    def update_profile(self,request,url,user):
        birthday = career = bio = ''
        p = user.profile
        for k,v in request.POST.iteritems():
            if 'birth' in k: p.birthday = self.convert_datetime(v)
            elif 'career' in k: p.career = v
            elif 'bio' in k: p.bio = v
        p.save()
        return response('Added informations to profile successfully')
    def finish_tutorial(self,request):
        whitespace = ' '
        data = request.POST
        name = request.COOKIES['username']
        u = User.objects.filter(username=name)[0]
        if 'name' in data: 
            lname = data['name'].split() 
            u.first_name,u.last_name = lname[0],whitespace.join(lname[1:])
        u.save()
        request.session['user'] = name
        if len(request.POST) is 0: return response('Added informations to profile successfully')#return redirect('/')
        else: return self.update_profile(request,'/',u)
    
class Authentication(Socialize):
    def social_update(self,request,typesoc,profile):
        data = request.REQUEST
        u = self.current_user(request)
        p = Profile.objects.filter(user=u)[0]
        if 'google' in typesoc: p.google_token = profile['google_token'] 
        elif 'twitter' in typesoc: p.twitter_token = '%s;%s' % (profile['key'],profile['secret'])
        elif 'facebook' in typesoc: p.facebook_token = profile['facebook_token']
        p.save()       
        return redirect('/')
    def social_register(self,request,typesoc,profile):
        data = request.REQUEST
        whitespace = ' '; r = None;
        facebook = twitter = google = ''
        if 'google' in typesoc:
            username = profile['name'].lower()
            google = profile['google_token']
        elif 'twitter' in typesoc:
            username = profile['screen_name']
            twitter = '%s;%s' % (profile['key'],profile['secret'])
        elif 'facebook' in typesoc:
            username = profile['link'].split('/')[-1:][0]
            facebook = profile['facebook_token']
        # Ja registrado, fazer login social
        if len(list(User.objects.filter(username=username))) > 0:
            request.session['user'] = username
            r = redirect('/')
        # Nao registrado, gravando chaves sociais e perfil e redirecionando para tutorial
        else: 
            u = User.objects.create_user(username,password=User.objects.make_random_password())
            p = Profile(user=u,facebook_token=facebook,twitter_token=twitter,google_token=google)
            p.save()
            r = redirect('tutorial?social=%s'%data['social'])
            r.set_cookie('username',username)
        r.set_cookie('permissions','super')
        return r
    def authenticate(self,request):
        data = request.REQUEST
        if 'profile' in data:
            profile = self.json_decode(data['profile']); t = data['social']
            # Atualizacao do perfil com tokens sociais
            if 'user' in request.session: return self.social_update(request,t,profile)
            # Registro do perfil com token social
            else: return self.social_register(request,t,profile)
        elif 'username' not in data or 'password' not in data:
            return response(json.dumps({'error':'User or password missing'}),mimetype='application/json')
        else:
            username = data['username']
            password = data['password']
            exists = User.objects.filter(username=username)
            if exists:
                if exists[0].check_password(password):
                    obj = json.dumps({'username':username,'userid':exists[0].id})
                    request.session['user'] = username
                    r = response(json.dumps({'success':'Login successful'}),
                                    mimetype = 'application/json')
                    r.set_cookie('permissions','super')
                    return r
                else:
                    obj = json.dumps({'error':'User or password wrong'})
                    return response(obj,mimetype='application/json')
            else:
                obj = json.dumps({'error':'User does not exist'})
                return response(obj,mimetype='application/json')
    def leave(self,request):
        del request.session['user']
        return response(json.dumps({'success':'Logout successful'}),mimetype='application/json')
    def view_register(self,request):
        return render(request,'register.html',{'static_url':settings.STATIC_URL,'hostname':request.get_host()},content_type='text/html')
    def participate(self,request):
        whitespace = ' '
        username = password = first_name = last_name = ''
        for k,v in request.POST.iteritems():
            if 'username' in k:
                u = User.objects.filter(username=v)
                if len(u) > 0: return response('Username already exists')
                else: username = v
            elif 'password' in k:
                if v not in request.POST['repeatpassword']: return response('Password mismatch')
                else: password = v
            elif 'name' in k: first_name,last_name = whitespace.join(v.split()[:1]),whitespace.join(v.split()[1:])
        user = User(username=username,first_name=first_name,last_name=last_name)
        user.set_password(password)
        user.save()
        r = redirect('/Socialize/tutorial')
        r.set_cookie('username',username)
        r.set_cookie('permissions','super')
        return r

class Twitter(Socialize):
    def update_status(self,request):
        u = self.current_user(request)
        if len(request.GET['content']) > 137: 
            short = unicode('%s...' % (request.GET['content'][:137]))
        else: short = unicode('%s' % (request.GET['content']))
        tokens = u.profile.twitter_token
        if not tokens: tokens = self.own_access()['twitter_token']
        data = {'status':short.encode('utf-8')}
        self.oauth_post_request('/statuses/update.json',tokens,data,'twitter')
        return response('Published posting successfully on Twitter')

class Facebook(Socialize):
    def update_status(self,request):
        u = self.current_user(request)
        token = u.profile.facebook_token
        text = unicode('%s' % request.GET['content'])
        data = {'message':text.encode('utf-8')}
        if 'id' in request.REQUEST: url = '/%s/feed' % request.REQUEST['id']
        else: url = '/me/feed'
        self.oauth_post_request(url,token,data,'facebook')
        return response('Published posting successfully on Facebook')
    def send_event(self,request):
        u = self.current_user(request)
        token = u.profile.facebook_token
        name = dates = descr = local = value = '' 
        for k,v in request.REQUEST.iteritems():
            if 'name' in k: name = v.encode('utf-8')
            elif 'deadline' in k: dates = v
            elif 'description' in k: descr = v.encode('utf-8')
            elif 'location' in k: local = v.encode('utf-8')
            elif 'value' in k: value = v
        date = self.convert_datetime(dates)
        url = 'http://%s/Socialize/basket?alt=redir&id=%s&value=%s&token=@@'%(settings.Socialize_URL,value,name)
        data = {'name':name,'start_time':date,'description':descr,'location':local,'ticket_uri':url}
        id = json.loads(self.oauth_post_request("/me/events",token,data,'facebook'))['id']
        return response(id)
    def send_event_cover(self,request):
        u = self.current_user(request)
        token = u.profile.facebook_token
        ident = request.REQUEST['id']
        photo = request.REQUEST['url']
        self.oauth_post_request('/%s'%ident,token,{'cover_url':photo},'facebook')
        return response('Published image cover on event successfully on Facebook')

class Coins(Socialize):
    def discharge(self,request):
        userid = request.REQUEST['userid']
        values = request.REQUEST['value']
        u = Profile.objects.filter(user=(userid))[0]
        u.credit -= int(values)
        u.save()
        j = json.dumps({'objects':{
            'userid':userid,
            'value':u.credit
        }})
        return response(j,mimetype='application/json')
    def recharge(self,request):
        userid = request.REQUEST['userid']
        values = request.REQUEST['value']
        u = Profile.objects.filter(user=(userid))[0]
        u.credit += int(values)
        u.save()
        json.dumps({'objects':{
            'userid': userid,
            'value': u.credit
        }})
        return response(j,mimetype='application/json')
    def balance(self,request):
        userid = request.GET['userid']
        json.dumps({'objects':{
            'userid': userid,
            'value': Profile.objects.filter(user=int(userid))[0].credit
        }})
        return response(j,mimetype='application/json')

class OAuthError(RuntimeError):
    """Generic exception class."""
    def __init__(self, message='OAuth error occured.'):
        self.message = message


class OAuth20Authentication(Authentication):
    """
    OAuth authenticator. 

    This Authentication method checks for a provided HTTP_AUTHORIZATION
    and looks up to see if this is a valid OAuth Access Token
    """
    def __init__(self, realm='API'):
        self.realm = realm

    def is_authenticated(self, request, **kwargs):
        """
        Verify 2-legged oauth request. Parameters accepted as
        values in "Authorization" header, or as a GET request
        or in a POST body.
        """
        logging.info("OAuth20Authentication")

        try:
            key = request.GET.get('oauth_consumer_key')
            if not key:
                key = request.POST.get('oauth_consumer_key')
            if not key:
                auth_header_value = request.META.get('HTTP_AUTHORIZATION')
                if auth_header_value:
                    key = auth_header_value.split(' ')[1]
            if not key:
                logging.error('OAuth20Authentication. No consumer_key found.')
                return None
            """
            If verify_access_token() does not pass, it will raise an error
            """
            token = verify_access_token(key)

            # If OAuth authentication is successful, set the request user to the token user for authorization
            request.user = token.user

            # If OAuth authentication is successful, set oauth_consumer_key on request in case we need it later
            request.META['oauth_consumer_key'] = key
            return True
        except KeyError, e:
            logging.exception("Error in OAuth20Authentication.")
            request.user = AnonymousUser()
            return False
        except Exception, e:
            logging.exception("Error in OAuth20Authentication.")
            return False
        return True

def verify_access_token(key):
    # Check if key is in AccessToken key
    try:
        token = AccessToken.objects.get(token=key)

        # Check if token has expired
        if token.expires < timezone.now():
            raise OAuthError('AccessToken has expired.')
    except AccessToken.DoesNotExist, e:
        raise OAuthError("AccessToken not found at all.")

    logging.info('Valid access')
    return token



#
# This file is part of Efforia project.
#
# Copyright (C) 2011-2013 William Oliveira de Lagos <william@efforia.com.br>
#
# Efforia is free software: you can redistribute it and/or modify
# it under the terms of the Lesser GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Efforia is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with Efforia. If not, see <http://www.gnu.org/licenses/>.
#

from django.db.models import *
from django.conf import settings
from django.contrib.auth.models import User
from django.template import Context,Template
from datetime import date

locale = settings.LOCALE_DATE

class Profile(Model):
    user = ForeignKey(User,related_name='+',unique=True)
    coins = IntegerField(default=0)
    visual = CharField(default="",max_length=100)
    career = CharField(default='',max_length=50)
    birthday = DateTimeField(default=date.today())
    google_token = TextField(default="",max_length=120)
    twitter_token = TextField(default="",max_length=120)
    facebook_token = TextField(default="",max_length=120)
    bio = TextField(default='',max_length=140)
    date = DateTimeField(default=date.today(),auto_now_add=True)
    def years_old(self): return datetime.timedelta(self.birthday,date.today)
    def token(self): return ''
    def get_username(self): return self.user.username
    def month(self): return locale[self.date.month-1]
    def render(self):
        source = """
            <div class="col-xs-12 col-sm-6 col-md-3 col-lg-2 brick">
                <a class="block profile" href="#" style="display:block; background:black">
                <div class="box profile">
                <div class="content">
                <h2 class="name">{{ firstname }}</h2>
                <div class="centered">{{ career }}</div>
                </div>
                {% if visual %}
                    <img src="{{ visual }}" width="100%"/>
                {% else %}
                    <h1 class="centered"><span class="glyphicon glyphicon-user big-glyphicon"></span></h1>
                {% endif %}
                <div class="content centered">
                {{ bio }}
                <div class="id hidden">{{ id }}</div></div></div>
                <div class="date"> Entrou em {{ day }} de {{month}}</div>
            </a></div>
        """
        return Template(source).render(Context({
            'firstname': self.user.first_name,
            'career':    self.career,
            'id':        self.id,
            'visual':    self.visual,
            'bio':       self.bio,
            'day':       self.date.day,
            'month':     self.month
        }))

class Followed(Model):
    followed = IntegerField(default=1)
    follower = IntegerField(default=2)
    date = DateTimeField(auto_now_add=True)

Profile.year = property(lambda p: p.years_old())
Profile.name = property(lambda p: p.get_username())
User.profile = property(lambda u: Profile.objects.get_or_create(user=u)[0])


#
# This file is part of Efforia project.
#
# Copyright (C) 2011-2013 William Oliveira de Lagos <william@efforia.com.br>
#
# Efforia is free software: you can redistribute it and/or modify
# it under the terms of the Lesser GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Efforia is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with Efforia. If not, see <http://www.gnu.org/licenses/>.
#

from django.conf.urls import patterns,url,include

urlpatterns = patterns('socialize.views',    
    (r'^profile','profile'),
    (r'^enter','authenticate'),
    (r'^leave','leave'),
    (r'^delete','delete'),
    (r'^userid','ids'),
    (r'^search','search'),
    (r'^explore','search'),
    (r'^known','explore'),
    (r'^following','following'),
    (r'^follow','follow'),
    (r'^unfollow','unfollow'),
    (r'^twitter/post','twitter_post'),
    (r'^facebook/post','facebook_post'),
    (r'^facebook/eventcover','facebook_eventcover'),
    (r'^facebook/event','facebook_event'),
    (r'^participate','participate'),
    (r'^tutorial','tutorial'),
    (r'^discharge','discharge'),
    (r'^recharge','recharge'),
    (r'^balance','balance'),
)



#
# This file is part of Efforia project.
#
# Copyright (C) 2011-2013 William Oliveira de Lagos <william@efforia.com.br>
#
# Efforia is free software: you can redistribute it and/or modify
# it under the terms of the Lesser GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Efforia is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with Efforia. If not, see <http://www.gnu.org/licenses/>.
#

# ATTENTION: Deprecated module.


import json
from StringIO import StringIO
from xml.dom.minidom import parseString

try:
    import gdata.youtube
    import gdata.media
    from dropbox import client, rest, session
except ImportError,e:
    pass

#apis = json.load(open('settings.json','r'))
#google_api = apis['social']['google']
google_api = ('','')

class Dropbox():
    def __init__(self):
        APP_KEY = '30pb1xxpccvhfqo'
        APP_SECRET = 'kap2qg8dt2cp7cv'
        ACCESS_TYPE = 'app_folder'
        self.sess = session.DropboxSession(APP_KEY, APP_SECRET, ACCESS_TYPE)
        request_token = 's8123g2tz0fb73a'
        request_token_secret = 'kwsa9sapz264uq5'
        access_token = 'q6lds714ncu45k3'
        access_token_secret = 'elvc3gmgbw8b99f'
        self.sess.set_request_token(request_token,request_token_secret)
        self.sess.set_token(access_token,access_token_secret)
    def upload_and_share(self,stream):
        cli = client.DropboxClient(self.sess)
        image_io = StringIO(stream)
        response = cli.put_file('/eimg.png',image_io)
        results = cli.share(response['path'])
        return results['url']

class StreamService():
    def __init__(self):
        self.developer_key = "AI39si7wyQ0h6KhpWLhZfJa-U4mU65rO3Dj-05grmYkZk-kn_sv8br5UdDIEORwG-itcRn5wSBTFbgu02KyR_FhSQNaR0QbvSQ"
        self.client_id = google_api['client_id']
    def videos_by_user(self,username):
        uri = 'https://gdata.youtube.com/feeds/api/users/%s/uploads?alt=json' % username
        return self.do_request(uri)
    def video_thumbnail(self,token,access_token):
        actoken = self.refresh_google_token(access_token)
        uri = 'https://gdata.youtube.com/feeds/api/users/default/uploads/%s?access_token=%s' % (token,actoken)
        thumbnail = parseString(self.do_request(uri)).getElementsByTagName('media:thumbnail')[0].attributes['url'].value
        return str(thumbnail)
    def video_entry(self,title,description,keywords,access_token):
        media_group = gdata.media.Group(title=gdata.media.Title(text=title),
                                        description=gdata.media.Description(description_type='plain',text=description),
                                        keywords=gdata.media.Keywords(text='efforia'),
                                        category=[gdata.media.Category(text='Entertainment',
                                                                       scheme='http://gdata.youtube.com/schemas/2007/categories.cat',
                                                                       label='Entertainment')],
                                        player=None)
                                        #private=gdata.media.Private())
        video_entry = gdata.youtube.YouTubeVideoEntry(media=media_group) 
        url,token = self.get_upload_token(video_entry,access_token)
        return url,token
    
    def get_upload_token(self,video_entry,access_token):
        actoken = self.refresh_google_token(access_token)
        print actoken
        headers = {
                   'Authorization': 'OAuth %s' % actoken,
                   'X-gdata-key': 'key=%s' % self.developer_key,
                   'Content-type': 'application/atom+xml'
        }
        response = self.do_request('https://gdata.youtube.com/action/GetUploadToken',str(video_entry),headers)
        print response
        url = parseString(response).getElementsByTagName('url')[0].childNodes[0].data
        token = parseString(response).getElementsByTagName('token')[0].childNodes[0].data
        return url,token
        
    def search_video(self,search_terms):
        pass



#
# This file is part of Efforia project.
#
# Copyright (C) 2011-2013 William Oliveira de Lagos <william@efforia.com.br>
#
# Efforia is free software: you can redistribute it and/or modify
# it under the terms of the Lesser GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Efforia is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with Efforia. If not, see <http://www.gnu.org/licenses/>.
#

from django import forms
from crispy_forms.helper import FormHelper
from crispy_forms.layout import Layout, Div, Hidden, HTML, Field

class TutorialForm(forms.Form):
    career = forms.CharField(label='',widget=forms.TextInput(attrs={'placeholder':'No que voce trabalha atualmente?'}))
    birth  = forms.CharField(label='',widget=forms.TextInput(attrs={'placeholder':'Quando voce nasceu?'}))
    bio    = forms.CharField(label='',widget=forms.Textarea(attrs={'rows':5,'placeholder':'Fale um pouco sobre voce.'}))
    def __init__(self, *args, **kwargs):
        self.helper = FormHelper()
        self.helper.form_class = 'form-signin'
        self.helper.form_action = '/efforia/tutorial'
        self.helper.layout = Layout(
            Div(Field('career',css_class='form-control'),css_class='form-group'),
            Div(Field('birth',css_class='datepicker form-control'),css_class='form-group'),
            Div(Field('bio',css_class='form-control'),css_class='form-group'),
        )
        super(TutorialForm, self).__init__(*args, **kwargs)